@@ -1,7 +1,7 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-14.
+# Conversion routines for ISO-8859-15.
 # Copyright (C) 2002-2017 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_14;
+package Locale::RecodeData::ISO_8859_15;
 
 use strict;
 
@@ -187,37 +187,37 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0x1e02,
-    0x1e03,
+    0x00a1,
+    0x00a2,
     0x00a3,
-    0x010a,
-    0x010b,
-    0x1e0a,
+    0x20ac,
+    0x00a5,
+    0x0160,
     0x00a7,
-    0x1e80,
+    0x0161,
     0x00a9,
-    0x1e82,
-    0x1e0b,
-    0x1ef2,
+    0x00aa,
+    0x00ab,
+    0x00ac,
     0x00ad,
     0x00ae,
-    0x0178,
-    0x1e1e,
-    0x1e1f,
-    0x0120,
-    0x0121,
-    0x1e40,
-    0x1e41,
+    0x00af,
+    0x00b0,
+    0x00b1,
+    0x00b2,
+    0x00b3,
+    0x017d,
+    0x00b5,
     0x00b6,
-    0x1e56,
-    0x1e81,
-    0x1e57,
-    0x1e83,
-    0x1e60,
-    0x1ef3,
-    0x1e84,
-    0x1e85,
-    0x1e61,
+    0x00b7,
+    0x017e,
+    0x00b9,
+    0x00ba,
+    0x00bb,
+    0x0152,
+    0x0153,
+    0x0178,
+    0x00bf,
     0x00c0,
     0x00c1,
     0x00c2,
@@ -234,21 +234,21 @@ my @to_ucs4 = (
     0x00cd,
     0x00ce,
     0x00cf,
-    0x0174,
+    0x00d0,
     0x00d1,
     0x00d2,
     0x00d3,
     0x00d4,
     0x00d5,
     0x00d6,
-    0x1e6a,
+    0x00d7,
     0x00d8,
     0x00d9,
     0x00da,
     0x00db,
     0x00dc,
     0x00dd,
-    0x0176,
+    0x00de,
     0x00df,
     0x00e0,
     0x00e1,
@@ -266,21 +266,21 @@ my @to_ucs4 = (
     0x00ed,
     0x00ee,
     0x00ef,
-    0x0175,
+    0x00f0,
     0x00f1,
     0x00f2,
     0x00f3,
     0x00f4,
     0x00f5,
     0x00f6,
-    0x1e6b,
+    0x00f7,
     0x00f8,
     0x00f9,
     0x00fa,
     0x00fb,
     0x00fc,
     0x00fd,
-    0x0177,
+    0x00fe,
     0x00ff,
 );
 
@@ -446,37 +446,37 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xe1\xb8\x82",
-    "\xe1\xb8\x83",
+    "\xc2\xa1",
+    "\xc2\xa2",
     "\xc2\xa3",
-    "\xc4\x8a",
-    "\xc4\x8b",
-    "\xe1\xb8\x8a",
+    "\xe2\x82\xac",
+    "\xc2\xa5",
+    "\xc5\xa0",
     "\xc2\xa7",
-    "\xe1\xba\x80",
+    "\xc5\xa1",
     "\xc2\xa9",
-    "\xe1\xba\x82",
-    "\xe1\xb8\x8b",
-    "\xe1\xbb\xb2",
+    "\xc2\xaa",
+    "\xc2\xab",
+    "\xc2\xac",
     "\xc2\xad",
     "\xc2\xae",
-    "\xc5\xb8",
-    "\xe1\xb8\x9e",
-    "\xe1\xb8\x9f",
-    "\xc4\xa0",
-    "\xc4\xa1",
-    "\xe1\xb9\x80",
-    "\xe1\xb9\x81",
+    "\xc2\xaf",
+    "\xc2\xb0",
+    "\xc2\xb1",
+    "\xc2\xb2",
+    "\xc2\xb3",
+    "\xc5\xbd",
+    "\xc2\xb5",
     "\xc2\xb6",
-    "\xe1\xb9\x96",
-    "\xe1\xba\x81",
-    "\xe1\xb9\x97",
-    "\xe1\xba\x83",
-    "\xe1\xb9\xa0",
-    "\xe1\xbb\xb3",
-    "\xe1\xba\x84",
-    "\xe1\xba\x85",
-    "\xe1\xb9\xa1",
+    "\xc2\xb7",
+    "\xc5\xbe",
+    "\xc2\xb9",
+    "\xc2\xba",
+    "\xc2\xbb",
+    "\xc5\x92",
+    "\xc5\x93",
+    "\xc5\xb8",
+    "\xc2\xbf",
     "\xc3\x80",
     "\xc3\x81",
     "\xc3\x82",
@@ -493,21 +493,21 @@ my @to_utf8 = (
     "\xc3\x8d",
     "\xc3\x8e",
     "\xc3\x8f",
-    "\xc5\xb4",
+    "\xc3\x90",
     "\xc3\x91",
     "\xc3\x92",
     "\xc3\x93",
     "\xc3\x94",
     "\xc3\x95",
     "\xc3\x96",
-    "\xe1\xb9\xaa",
+    "\xc3\x97",
     "\xc3\x98",
     "\xc3\x99",
     "\xc3\x9a",
     "\xc3\x9b",
     "\xc3\x9c",
     "\xc3\x9d",
-    "\xc5\xb6",
+    "\xc3\x9e",
     "\xc3\x9f",
     "\xc3\xa0",
     "\xc3\xa1",
@@ -525,21 +525,21 @@ my @to_utf8 = (
     "\xc3\xad",
     "\xc3\xae",
     "\xc3\xaf",
-    "\xc5\xb5",
+    "\xc3\xb0",
     "\xc3\xb1",
     "\xc3\xb2",
     "\xc3\xb3",
     "\xc3\xb4",
     "\xc3\xb5",
     "\xc3\xb6",
-    "\xe1\xb9\xab",
+    "\xc3\xb7",
     "\xc3\xb8",
     "\xc3\xb9",
     "\xc3\xba",
     "\xc3\xbb",
     "\xc3\xbc",
     "\xc3\xbd",
-    "\xc5\xb7",
+    "\xc3\xbe",
     "\xc3\xbf",
 );
 
@@ -705,12 +705,29 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
+    0x000000a1 => "\xa1",
+    0x000000a2 => "\xa2",
     0x000000a3 => "\xa3",
+    0x000000a5 => "\xa5",
     0x000000a7 => "\xa7",
     0x000000a9 => "\xa9",
+    0x000000aa => "\xaa",
+    0x000000ab => "\xab",
+    0x000000ac => "\xac",
     0x000000ad => "\xad",
     0x000000ae => "\xae",
+    0x000000af => "\xaf",
+    0x000000b0 => "\xb0",
+    0x000000b1 => "\xb1",
+    0x000000b2 => "\xb2",
+    0x000000b3 => "\xb3",
+    0x000000b5 => "\xb5",
     0x000000b6 => "\xb6",
+    0x000000b7 => "\xb7",
+    0x000000b9 => "\xb9",
+    0x000000ba => "\xba",
+    0x000000bb => "\xbb",
+    0x000000bf => "\xbf",
     0x000000c0 => "\xc0",
     0x000000c1 => "\xc1",
     0x000000c2 => "\xc2",
@@ -727,18 +744,21 @@ my %from_ucs4 = (
     0x000000cd => "\xcd",
     0x000000ce => "\xce",
     0x000000cf => "\xcf",
+    0x000000d0 => "\xd0",
     0x000000d1 => "\xd1",
     0x000000d2 => "\xd2",
     0x000000d3 => "\xd3",
     0x000000d4 => "\xd4",
     0x000000d5 => "\xd5",
     0x000000d6 => "\xd6",
+    0x000000d7 => "\xd7",
     0x000000d8 => "\xd8",
     0x000000d9 => "\xd9",
     0x000000da => "\xda",
     0x000000db => "\xdb",
     0x000000dc => "\xdc",
     0x000000dd => "\xdd",
+    0x000000de => "\xde",
     0x000000df => "\xdf",
     0x000000e0 => "\xe0",
     0x000000e1 => "\xe1",
@@ -756,50 +776,30 @@ my %from_ucs4 = (
     0x000000ed => "\xed",
     0x000000ee => "\xee",
     0x000000ef => "\xef",
+    0x000000f0 => "\xf0",
     0x000000f1 => "\xf1",
     0x000000f2 => "\xf2",
     0x000000f3 => "\xf3",
     0x000000f4 => "\xf4",
     0x000000f5 => "\xf5",
     0x000000f6 => "\xf6",
+    0x000000f7 => "\xf7",
     0x000000f8 => "\xf8",
     0x000000f9 => "\xf9",
     0x000000fa => "\xfa",
     0x000000fb => "\xfb",
     0x000000fc => "\xfc",
     0x000000fd => "\xfd",
+    0x000000fe => "\xfe",
     0x000000ff => "\xff",
-    0x0000010a => "\xa4",
-    0x0000010b => "\xa5",
-    0x00000120 => "\xb2",
-    0x00000121 => "\xb3",
-    0x00000174 => "\xd0",
-    0x00000175 => "\xf0",
-    0x00000176 => "\xde",
-    0x00000177 => "\xfe",
-    0x00000178 => "\xaf",
-    0x00001e02 => "\xa1",
-    0x00001e03 => "\xa2",
-    0x00001e0a => "\xa6",
-    0x00001e0b => "\xab",
-    0x00001e1e => "\xb0",
-    0x00001e1f => "\xb1",
-    0x00001e40 => "\xb4",
-    0x00001e41 => "\xb5",
-    0x00001e56 => "\xb7",
-    0x00001e57 => "\xb9",
-    0x00001e60 => "\xbb",
-    0x00001e61 => "\xbf",
-    0x00001e6a => "\xd7",
-    0x00001e6b => "\xf7",
-    0x00001e80 => "\xa8",
-    0x00001e81 => "\xb8",
-    0x00001e82 => "\xaa",
-    0x00001e83 => "\xba",
-    0x00001e84 => "\xbd",
-    0x00001e85 => "\xbe",
-    0x00001ef2 => "\xac",
-    0x00001ef3 => "\xbc",
+    0x00000152 => "\xbc",
+    0x00000153 => "\xbd",
+    0x00000160 => "\xa6",
+    0x00000161 => "\xa8",
+    0x00000178 => "\xbe",
+    0x0000017d => "\xb4",
+    0x0000017e => "\xb8",
+    0x000020ac => "\xa4",
 );
 
 sub _recode
@@ -827,7 +827,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_14 - Conversion routines for ISO-8859-14
+Locale::RecodeData::ISO_8859_15 - Conversion routines for ISO-8859-15
 
 =head1 SYNOPSIS
 
@@ -836,15 +836,13 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-14.
+routines for ISO-8859-15.
 
 =head1 COMMENTS
 
 The following comments have been extracted from the original charmap:
 
  automatically generated from the charDB
- alias LATIN8
- alias L8
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -1017,37 +1015,37 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A1 |  00001E02 | LATIN CAPITAL LETTER B WITH DOT ABOVE
-    A2 |  00001E03 | LATIN SMALL LETTER B WITH DOT ABOVE
+    A1 |  000000A1 | INVERTED EXCLAMATION MARK
+    A2 |  000000A2 | CENT SIGN
     A3 |  000000A3 | POUND SIGN
-    A4 |  0000010A | LATIN CAPITAL LETTER C WITH DOT ABOVE
-    A5 |  0000010B | LATIN SMALL LETTER C WITH DOT ABOVE
-    A6 |  00001E0A | LATIN CAPITAL LETTER D WITH DOT ABOVE
+    A4 |  000020AC | EURO SIGN
+    A5 |  000000A5 | YEN SIGN
+    A6 |  00000160 | LATIN CAPITAL LETTER S WITH CARON
     A7 |  000000A7 | SECTION SIGN
-    A8 |  00001E80 | LATIN CAPITAL LETTER W WITH GRAVE
+    A8 |  00000161 | LATIN SMALL LETTER S WITH CARON
     A9 |  000000A9 | COPYRIGHT SIGN
-    AA |  00001E82 | LATIN CAPITAL LETTER W WITH ACUTE
-    AB |  00001E0B | LATIN SMALL LETTER D WITH DOT ABOVE
-    AC |  00001EF2 | LATIN CAPITAL LETTER Y WITH GRAVE
+    AA |  000000AA | FEMININE ORDINAL INDICATOR
+    AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
+    AC |  000000AC | NOT SIGN
     AD |  000000AD | SOFT HYPHEN
     AE |  000000AE | REGISTERED SIGN
-    AF |  00000178 | LATIN CAPITAL LETTER Y WITH DIAERESIS
-    B0 |  00001E1E | LATIN CAPITAL LETTER F WITH DOT ABOVE
-    B1 |  00001E1F | LATIN SMALL LETTER F WITH DOT ABOVE
-    B2 |  00000120 | LATIN CAPITAL LETTER G WITH DOT ABOVE
-    B3 |  00000121 | LATIN SMALL LETTER G WITH DOT ABOVE
-    B4 |  00001E40 | LATIN CAPITAL LETTER M WITH DOT ABOVE
-    B5 |  00001E41 | LATIN SMALL LETTER M WITH DOT ABOVE
+    AF |  000000AF | MACRON
+    B0 |  000000B0 | DEGREE SIGN
+    B1 |  000000B1 | PLUS-MINUS SIGN
+    B2 |  000000B2 | SUPERSCRIPT TWO
+    B3 |  000000B3 | SUPERSCRIPT THREE
+    B4 |  0000017D | LATIN CAPITAL LETTER Z WITH CARON
+    B5 |  000000B5 | MICRO SIGN
     B6 |  000000B6 | PILCROW SIGN
-    B7 |  00001E56 | LATIN CAPITAL LETTER P WITH DOT ABOVE
-    B8 |  00001E81 | LATIN SMALL LETTER W WITH GRAVE
-    B9 |  00001E57 | LATIN SMALL LETTER P WITH DOT ABOVE
-    BA |  00001E83 | LATIN SMALL LETTER W WITH ACUTE
-    BB |  00001E60 | LATIN CAPITAL LETTER S WITH DOT ABOVE
-    BC |  00001EF3 | LATIN SMALL LETTER Y WITH GRAVE
-    BD |  00001E84 | LATIN CAPITAL LETTER W WITH DIAERESIS
-    BE |  00001E85 | LATIN SMALL LETTER W WITH DIAERESIS
-    BF |  00001E61 | LATIN SMALL LETTER S WITH DOT ABOVE
+    B7 |  000000B7 | MIDDLE DOT
+    B8 |  0000017E | LATIN SMALL LETTER Z WITH CARON
+    B9 |  000000B9 | SUPERSCRIPT ONE
+    BA |  000000BA | MASCULINE ORDINAL INDICATOR
+    BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
+    BC |  00000152 | LATIN CAPITAL LIGATURE OE
+    BD |  00000153 | LATIN SMALL LIGATURE OE
+    BE |  00000178 | LATIN CAPITAL LETTER Y WITH DIAERESIS
+    BF |  000000BF | INVERTED QUESTION MARK
     C0 |  000000C0 | LATIN CAPITAL LETTER A WITH GRAVE
     C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
     C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
@@ -1064,21 +1062,21 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
     CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
     CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
-    D0 |  00000174 | LATIN CAPITAL LETTER W WITH CIRCUMFLEX
+    D0 |  000000D0 | LATIN CAPITAL LETTER ETH
     D1 |  000000D1 | LATIN CAPITAL LETTER N WITH TILDE
     D2 |  000000D2 | LATIN CAPITAL LETTER O WITH GRAVE
     D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
     D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
     D5 |  000000D5 | LATIN CAPITAL LETTER O WITH TILDE
     D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
-    D7 |  00001E6A | LATIN CAPITAL LETTER T WITH DOT ABOVE
+    D7 |  000000D7 | MULTIPLICATION SIGN
     D8 |  000000D8 | LATIN CAPITAL LETTER O WITH STROKE
     D9 |  000000D9 | LATIN CAPITAL LETTER U WITH GRAVE
     DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
     DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
     DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
     DD |  000000DD | LATIN CAPITAL LETTER Y WITH ACUTE
-    DE |  00000176 | LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
+    DE |  000000DE | LATIN CAPITAL LETTER THORN
     DF |  000000DF | LATIN SMALL LETTER SHARP S
     E0 |  000000E0 | LATIN SMALL LETTER A WITH GRAVE
     E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
@@ -1096,21 +1094,21 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
     EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
     EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
-    F0 |  00000175 | LATIN SMALL LETTER W WITH CIRCUMFLEX
+    F0 |  000000F0 | LATIN SMALL LETTER ETH
     F1 |  000000F1 | LATIN SMALL LETTER N WITH TILDE
     F2 |  000000F2 | LATIN SMALL LETTER O WITH GRAVE
     F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
     F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
     F5 |  000000F5 | LATIN SMALL LETTER O WITH TILDE
     F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
-    F7 |  00001E6B | LATIN SMALL LETTER T WITH DOT ABOVE
+    F7 |  000000F7 | DIVISION SIGN
     F8 |  000000F8 | LATIN SMALL LETTER O WITH STROKE
     F9 |  000000F9 | LATIN SMALL LETTER U WITH GRAVE
     FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
     FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
     FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
     FD |  000000FD | LATIN SMALL LETTER Y WITH ACUTE
-    FE |  00000177 | LATIN SMALL LETTER Y WITH CIRCUMFLEX
+    FE |  000000FE | LATIN SMALL LETTER THORN
     FF |  000000FF | LATIN SMALL LETTER Y WITH DIAERESIS
 
 
